%define nginx_user nginx
%define nginx_group %{nginx_user}
%define nginx_home /var/lib/nginx
%define nginx_home_tmp %{nginx_home}/tmp
%define nginx_logdir /var/log/nginx
%define nginx_confdir %{_sysconfdir}/nginx
%define nginx_datadir %{_datadir}/nginx
%define nginx_webroot %{nginx_datadir}/html

Summary:	Robust, small and high performance http and reverse proxy server
Name:		nginx
Version:	1.6.2
%define subrel	1
Release:	%mkrel 5
Group:		System/Servers
# BSD License (two clause)
# http://www.freebsd.org/copyright/freebsd-license.html
License:	BSD
URL:		http://nginx.net/
Source0:	http://nginx.org/download/nginx-%{version}.tar.gz
Source1:	http://nginx.org/download/nginx-%{version}.tar.gz.asc
Source3:	%{name}.logrotate
Source4:	%{name}.sysconfig
Source5:	%{name}.service

Source6:	nginx.conf
Source7:	default.conf
Source8:	ssl.conf
Source9:	virtual.conf
Source100:	index.html
Source101:	poweredby.png
Source102:	nginx-logo.png
Source103:	50x.html
Source104:	404.html

Patch0003:	0003-Resolver-fixed-possible-segmentation-fault-on-DNS-fo.patch
Patch0004:	0004-Resolver-fixed-crashes-in-timeout-handler.patch
Patch0005:	0005-Resolver-fixed-CNAME-processing-for-several-requests.patch
Patch0006:	0006-Resolver-changed-the-ngx_resolver_create_-_query-arg.patch
Patch0007:	0007-Resolver-fixed-use-after-free-memory-accesses-with-C.patch
Patch0008:	0008-Resolver-limited-CNAME-recursion.patch

Requires(post):	rpm-helper >= 0.24.8-1
Requires(preun):	rpm-helper >= 0.24.8-1
BuildRequires:	GeoIP-devel
BuildRequires:	gd-devel
BuildRequires:	libxslt-devel
BuildRequires:	openssl-devel
BuildRequires:	pcre-devel
BuildRequires:	zlib-devel
BuildRequires:	perl-devel
BuildRequires:	perl(ExtUtils::Embed)
Requires:	pcre
Requires:	openssl
Provides:	webserver

%description
Nginx [engine x] is an HTTP(S) server, HTTP(S) reverse proxy and IMAP/POP3
proxy server written by Igor Sysoev.

%prep
%setup -q
%autopatch -p1

%build
%serverbuild
# nginx does not utilize a standard configure script.  It has its own
# and the standard configure options cause the nginx configure script
# to error out.  This is is also the reason for the DESTDIR environment
# variable.  The configure script(s) have been patched (Patch1 and
# Patch2) in order to support installing into a build environment.
export DESTDIR=%{buildroot}
./configure \
    --prefix=%{nginx_datadir} \
    --sbin-path=%{_sbindir}/%{name} \
    --conf-path=%{nginx_confdir}/%{name}.conf \
    --error-log-path=%{nginx_logdir}/error.log \
    --http-log-path=%{nginx_logdir}/access.log \
    --http-client-body-temp-path=%{nginx_home_tmp}/client_body \
    --http-proxy-temp-path=%{nginx_home_tmp}/proxy \
    --http-fastcgi-temp-path=%{nginx_home_tmp}/fastcgi \
    --http-uwsgi-temp-path=%{nginx_home_tmp}/uwsgi \
    --http-scgi-temp-path=%{nginx_home_tmp}/scgi \
    --pid-path=/run/%{name}.pid \
    --lock-path=/run/lock/subsys/%{name} \
    --user=%{nginx_user} \
    --group=%{nginx_group} \
    --with-file-aio \
    --with-ipv6 \
    --with-http_ssl_module \
    --with-http_spdy_module \
    --with-http_realip_module \
    --with-http_addition_module \
    --with-http_xslt_module \
    --with-http_image_filter_module \
    --with-http_geoip_module \
    --with-http_sub_module \
    --with-http_dav_module \
    --with-http_flv_module \
    --with-http_mp4_module \
    --with-http_gunzip_module \
    --with-http_gzip_static_module \
    --with-http_random_index_module \
    --with-http_secure_link_module \
    --with-http_degradation_module \
    --with-http_stub_status_module \
    --with-http_perl_module \
    --with-mail \
    --with-mail_ssl_module \
    --with-cc-opt="$CFLAGS $(pcre-config --cflags)" 

%make

%install
%makeinstall_std INSTALLDIRS=vendor

%{__install} -d -m 755 %{buildroot}%{_sysconfdir}/logrotate.d
%{__install} -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

%{__install} -d -m 755 %{buildroot}%{_sysconfdir}/sysconfig
%{__install} -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/sysconfig/%{name}

%{__install} -d -m 755 %{buildroot}%{_unitdir}
%{__install} -m 644 %{SOURCE5} %{buildroot}%{_unitdir}

%{__install} -m 644 %{SOURCE6} %{buildroot}%{nginx_confdir}

%{__install} -d -m 0755 %{buildroot}%{nginx_confdir}/conf.d
%{__install} -m 644 %{SOURCE7} %{SOURCE8} %{SOURCE9} \
    %{buildroot}%{nginx_confdir}/conf.d

%{__install} -d -m 0755 %{buildroot}%{nginx_home_tmp}
%{__install} -d -m 0755 %{buildroot}%{nginx_logdir}
%{__install} -d -m 0755 %{buildroot}%{nginx_webroot}

%{__install} -p -m 0644 %{SOURCE100} %{SOURCE101} %{SOURCE102} \
			%{SOURCE103} %{SOURCE104} \
			%{buildroot}%{nginx_webroot}

# add current version
perl -pi -e "s|_VERSION_|%{version}|g" %{buildroot}%{nginx_webroot}/index.html

# convert to UTF-8 all files that give warnings.
for textfile in CHANGES; do
    mv $textfile $textfile.old
    iconv --from-code ISO8859-1 --to-code UTF-8 --output $textfile $textfile.old
    rm -f $textfile.old
done

install -d %{buildroot}%{_mandir}/man8
install -m0644 man/*.8 %{buildroot}%{_mandir}/man8/

%pre
%_pre_useradd %{nginx_user} %{nginx_home} /bin/false

%post
%_post_service %{nginx_user}

%preun
%_preun_service %{nginx_user}

%postun
%_postun_userdel %{nginx_user}

%files
%doc LICENSE CHANGES README
%{nginx_datadir}
%{_sbindir}/%{name}
%{_mandir}/man3/%{name}.3pm*
%{_mandir}/man8/*
%{_unitdir}/%{name}.service
%dir %{nginx_confdir}
%dir %{nginx_confdir}/conf.d
%config(noreplace) %{nginx_confdir}/conf.d/*.conf
%config(noreplace) %{nginx_confdir}/win-utf
%config(noreplace) %{nginx_confdir}/%{name}.conf.default
%config(noreplace) %{nginx_confdir}/scgi_params
%config(noreplace) %{nginx_confdir}/scgi_params.default
%config(noreplace) %{nginx_confdir}/fastcgi.conf
%config(noreplace) %{nginx_confdir}/fastcgi.conf.default
%config(noreplace) %{nginx_confdir}/mime.types.default
%config(noreplace) %{nginx_confdir}/fastcgi_params
%config(noreplace) %{nginx_confdir}/fastcgi_params.default
%config(noreplace) %{nginx_confdir}/koi-win
%config(noreplace) %{nginx_confdir}/koi-utf
%config(noreplace) %{nginx_confdir}/%{name}.conf
%config(noreplace) %{nginx_confdir}/mime.types
%config(noreplace) %{nginx_confdir}/uwsgi_params
%config(noreplace) %{nginx_confdir}/uwsgi_params.default
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{perl_vendorarch}/auto/%{name}
%{perl_vendorarch}/%{name}.pm
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_home}
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_home_tmp}
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_logdir}


%changelog
* Fri Feb 12 2016 luigiwalser <luigiwalser> 1.6.2-5.1.mga5
+ Revision: 958850
- add patches from debian to fix CVE-2016-0742, CVE-2016-0746, CVE-2016-0747

* Mon Feb 16 2015 oden <oden> 1.6.2-5.mga5
+ Revision: 815158
- rebuilt for libgd-2.1.1

* Wed Oct 15 2014 umeabot <umeabot> 1.6.2-4.mga5
+ Revision: 749897
- Second Mageia 5 Mass Rebuild

* Thu Oct 09 2014 tv <tv> 1.6.2-3.mga5
+ Revision: 737725
- rebuild for new perl

* Tue Sep 16 2014 umeabot <umeabot> 1.6.2-2.mga5
+ Revision: 682881
- Mageia 5 Mass Rebuild

  + luigiwalser <luigiwalser>
    - 1.6.2 (fixes CVE-2014-3616)

* Mon Sep 01 2014 luigiwalser <luigiwalser> 1.6.1-1.mga5
+ Revision: 670758
- 1.6.1 (fixes CVE-2014-3556)

* Tue Jun 03 2014 pterjan <pterjan> 1.6.0-2.mga5
+ Revision: 630783
- Rebuild for perl 5.20

* Fri Apr 25 2014 thatsamguy <thatsamguy> 1.6.0-1.mga5
+ Revision: 617716
- update to new stable branch and release v1.6.0

* Wed Mar 19 2014 thatsamguy <thatsamguy> 1.5.12-1.mga5
+ Revision: 605596
- update to latest release 1.5.12 (fixes CVE-2014-0133)

* Tue Feb 11 2014 thatsamguy <thatsamguy> 1.5.10-1.mga5
+ Revision: 589567
- update to latest mainline release v1.5.10

* Tue Feb 04 2014 tv <tv> 1.4.4-2.mga5
+ Revision: 581925
- rebuild for new perl

* Wed Nov 20 2013 thatsamguy <thatsamguy> 1.4.4-1.mga4
+ Revision: 552017
- new version 1.4.4 to fix security issue (CVE-2013-4547)

* Tue Oct 22 2013 umeabot <umeabot> 1.4.3-4.mga4
+ Revision: 545013
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 thatsamguy <thatsamguy> 1.4.3-3.mga4
+ Revision: 500479
-revert to 1.4.3
-bump rel to 3 for prev logrotate fix
- remove obsolete file
- enable auth_request module
- switch logrotate to use systemd commands
- new version 1.5.6

* Thu Oct 10 2013 thatsamguy <thatsamguy> 1.4.3-2.mga4
+ Revision: 494697
-fixed conf file install location
-fixed log restart during logrotate
-enabled spdy module
-enabled gunzip module
-spec file cleanup

* Wed Oct 09 2013 guillomovitch <guillomovitch> 1.4.3-1.mga4
+ Revision: 494108
- new version 1.4.3

* Wed Aug 28 2013 tv <tv> 1.2.9-5.mga4
+ Revision: 472742
- rebuild for new perl

* Wed May 29 2013 tv <tv> 1.2.9-4.mga4
+ Revision: 430245
- rebuild for new perl

* Tue May 28 2013 luigiwalser <luigiwalser> 1.2.9-3.mga4
+ Revision: 429683
- re-add poweredby.png (used in index.html)

* Tue May 28 2013 oden <oden> 1.2.9-2.mga4
+ Revision: 429295
- rebuilt against libgd.so.3

* Mon May 13 2013 luigiwalser <luigiwalser> 1.2.9-1.mga3
+ Revision: 413086
- 1.2.9 (fixes CVE-2013-2070)

* Wed Mar 20 2013 tv <tv> 1.2.6-3.mga3
+ Revision: 404178
- rebuild for new perl...

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jan 04 2013 luigiwalser <luigiwalser> 1.2.6-1.mga3
+ Revision: 338529
- 1.2.6

* Sat Dec 01 2012 fwang <fwang> 1.2.5-2.mga3
+ Revision: 323813
- rebuild for new pcre

* Thu Nov 15 2012 fwang <fwang> 1.2.5-1.mga3
+ Revision: 317995
- new version 1.2.5

* Wed Sep 26 2012 fwang <fwang> 1.2.4-1.mga3
+ Revision: 297827
- new version 1.2.4

* Sat Sep 08 2012 guillomovitch <guillomovitch> 1.2.3-1.mga3
+ Revision: 290421
- new version

* Wed Aug 29 2012 tv <tv> 1.2.2-3.mga3
+ Revision: 285543
- rebuild for new perl

* Thu Aug 09 2012 tv <tv> 1.2.2-2.mga3
+ Revision: 280274
- drop sysv service

* Wed Jul 04 2012 fwang <fwang> 1.2.2-1.mga3
+ Revision: 267695
- new version 1.2.2

* Sat Jun 09 2012 shlomif <shlomif> 1.2.1-1.mga3
+ Revision: 258749
- New version - 1.2.1

* Wed May 30 2012 jquelin <jquelin> 1.2.0-2.mga3
+ Revision: 250255
- rebuild for perl 5.16

* Mon May 28 2012 fwang <fwang> 1.2.0-1.mga3
+ Revision: 247662
- new version 1.2.0

* Sat Apr 28 2012 tmb <tmb> 1.0.15-2.mga2
+ Revision: 233820
- Require rpm-helper >= 0.24.8-1 for systemd support

* Thu Apr 19 2012 fwang <fwang> 1.0.15-1.mga2
+ Revision: 231795
- new version 1.0.15

* Mon Mar 19 2012 guillomovitch <guillomovitch> 1.0.14-2.mga2
+ Revision: 224503
- drop last mandriva references (#3815)

* Mon Mar 19 2012 guillomovitch <guillomovitch> 1.0.14-1.mga2
+ Revision: 224303
+ rebuild (emptylog)

* Thu Mar 15 2012 guillomovitch <guillomovitch> 1.0.10-2.mga2
+ Revision: 223512
- sync configuration files with fedora package
- drop useless apache dependency
- spec cleanup
- systemd support

* Mon Jan 09 2012 fwang <fwang> 1.0.10-1.mga2
+ Revision: 193691
- new version 1.0.10

* Fri Nov 04 2011 fwang <fwang> 1.0.9-1.mga2
+ Revision: 162665
- new version 1.0.9

* Thu Oct 20 2011 tv <tv> 1.0.8-2.mga2
+ Revision: 156981
- rebuild for new perl

* Sun Oct 02 2011 fwang <fwang> 1.0.8-1.mga2
+ Revision: 150974
- new version 1.0.8

* Sun Sep 18 2011 dmorgan <dmorgan> 1.0.6-2.mga2
+ Revision: 144695
- Change apache-conf require

* Wed Aug 31 2011 fwang <fwang> 1.0.6-1.mga2
+ Revision: 136890
- new version 1.0.6

* Wed Jul 20 2011 fwang <fwang> 1.0.5-1.mga2
+ Revision: 127063
- rediff conf patch
- add signature
- new version 1.0.5

* Thu Jun 16 2011 tv <tv> 1.0.4-1.mga2
+ Revision: 108442
- new relase
- vendor is mga not mdv
- s/mdv/mga/

* Sat Jun 11 2011 jquelin <jquelin> 1.0.0-2.mga2
+ Revision: 103442
- perl 5.14

* Wed Apr 13 2011 tv <tv> 1.0.0-1.mga1
+ Revision: 84509
- new release

* Sun Feb 20 2011 dmorgan <dmorgan> 0.9.3-1.mga1
+ Revision: 54507
- imported package nginx

